==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/ts/Modify_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Modify</name>
    <message>
        <location filename="../Modify.js" line="+99"/>
        <source>Modification Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narzędzia modyfikacji</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show modification tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Pokaż narzędzi modyfikacji</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Modify</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Modyfikuj</translatorcomment>
        <translation type="unfinished">&amp;Modyfikuj</translation>
    </message>
</context>
<context>
    <name>ModifyCorner</name>
    <message>
        <location filename="../ModifyCorner.js" line="+86"/>
        <source>Choose corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Choose first entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz pierwszy podmiot</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Choose second entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wybierz drugi podmiot</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Set point</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Transform</name>
    <message>
        <location filename="../Transform.js" line="+47"/>
        <source>This tool requires a selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narzędzie to wymaga zaznaczenia</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/ts/Modify_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Modify</name>
    <message>
        <location filename="../Modify.js" line="+99"/>
        <source>Modification Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Narzędzia modyfikowania</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show modification tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyświetla narzędzia modyfikowania</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Modify</source>
        <translatorcomment>--exact match--
--file: qcad_pl.ts--
&amp;Modyfikuj</translatorcomment>
        <translation>&amp;Modyfikowanie</translation>
    </message>
</context>
<context>
    <name>ModifyCorner</name>
    <message>
        <location filename="../ModifyCorner.js" line="+86"/>
        <source>Choose corner</source>
        <translation>Proszę wskazać narożnik</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Choose first entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać pierwszy obiekt</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Choose second entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać drugi obiekt</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Set point</source>
        <translation>Proszę wskazać punkt</translation>
    </message>
</context>
<context>
    <name>Transform</name>
    <message>
        <location filename="../Transform.js" line="+47"/>
        <source>This tool requires a selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>To narzędzie wymaga zaznaczenia</translation>
    </message>
</context>
</TS>
